// Copyright 2014 Rouslan Solomakhin
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import 'package:passphrase_constructor/passphrase_constructor.dart';

import 'dart:math';
import 'package:unittest/unittest.dart';

/// Unit tests for the passphrase constructor.
void runTests() {
  var pass = new PassphraseConstructor(['hello', 'world', 'peace', 'love'],
                                       ['&^%', ')!(#'], ['123', '85'],
                                       new Random(0));

  test('Empty password', () =>
    expect(pass.construct(0, false, false, false),
           equals([]))
  );

  test('15 chars', () =>
    expect(pass.construct(15, false, false, false),
           equals(['hello', 'world', 'peace']))
  );

  test('14 chars', () =>
    expect(pass.construct(14, false, false, false),
           equals(['hello', 'world']))
  );

  test('Use specials', () =>
    expect(pass.construct(15, true, false, false),
           equals(['&^%', 'hello', 'world']))
  );

  test('Use numbers', () =>
    expect(pass.construct(15, false, true, false),
           equals(['hello', 'world', '123']))
  );

  test('Use specials and numbers', () =>
    expect(pass.construct(15, true, true, false),
           equals(['&^%', '123', 'hello']))
  );

  test('Use upper case', () =>
    expect(pass.construct(15, false, false, true),
           equals(['hEllo', 'world', 'peace']))
  );

  test('Not enough words', () =>
    expect(pass.construct(99, false, false, false),
           equals(
             ['hello', '85', '123', ')!(#', 'world', 'peace', 'love', '&^%']))
  );
}

// Entry point for Dart VM.
void main() {
  runTests();
}